@@ -5,6 +5,7 @@
 ##             arnost.komarek[AT]mff.cuni.cz
 ##
 ##  CREATED:   22/01/2008
+##             15/03/2017  .C call uses registered routines
 ##
 ##  FUNCTIONS:  MatSqrt
 ##
@@ -27,7 +28,7 @@ MatSqrt <- function(A)
 
   ldwork <- p*p
 
-  RES <- .C("sqrtGE", Asqrt.re=as.double(A),    Asqrt.im=double(p*p),     Vinv.re=double(p*p),  Vinv.im=double(p*p),  complexRES=integer(1),
+  RES <- .C(C_sqrtGE, Asqrt.re=as.double(A),    Asqrt.im=double(p*p),     Vinv.re=double(p*p),  Vinv.im=double(p*p),  complexRES=integer(1),
                       sqrt.lambda.re=double(p), sqrt.lambda.im=double(p), V.re=double(p*p),     V.im=double(p*p),
                       dwork=double(ldwork),     jpvt=integer(p),
                       err=as.integer(0),        p=as.integer(p),
